from setuptools import setup

setup(name='stat_distr',
      version='0.1',
      description='Statistic Distributions',
      packages=['stat_distr'],
      author = 'Anna Xenaki',
      author_mail= 'a.xenaki22@gmail.com',
      zip_safe=False)
